yakumo.nova.v2.volume_attachment.Manager

Package yakumo :: Package nova :: Package v2 :: Module volume_attachment :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
     base.SubManager --+
                       |
                      Manager

Manager class for volume attachment in Compute API v2

Nested Classes | [hide private]
| resource_class Resource class for volume attachment in Compute API v2

Instance Methods | [hide private]
attach(self, device=`'``__UNDEF__``'`, volume=`'``__UNDEF__``'`) Attach a volume | source code
Inherited from `base.SubManager`: `__init__` Inherited from `base.Manager`: `create`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``compute``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _hidden_methods = ``[``'``create``'``,` `'``update``'``]``
| _json_resource_key = ``'``volumeAttachment``'``
| _json_resources_key = ``'``volumeAttachments``'``
| _url_resource_path = ``'``/servers/%s/os-volume_attachments``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_id_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### attach(self, device=`'``__UNDEF__``'`, volume=`'``__UNDEF__``'`) | source code
Attach a volume Parameters: `device` (str) - device path on the guest OS (e.q. '/dev/sda') `volume` (yakumo.volume.Resource) - Volume (required)

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('device', 'device', mapper.Noop), ('serve
      r', 'serverId', mapper.Resource('nova.server')), ('volume', 'volumeId'
      , mapper.Resource('volume')),]